package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstrainPleaseApproveResultMapper;
import com.steerinfo.dil.model.TmstrainPleaseApproveResult;
import com.steerinfo.dil.service.ITmstrainPleaseApproveResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * TmstrainPleaseApproveResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-30 02:09
 * 类描述
 * 修订历史：
 * 日期：2021-08-30
 * 作者：generator
 * 参考：
 * 描述：TmstrainPleaseApproveResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstrainPleaseApproveResultService")
public class TmstrainPleaseApproveResultServiceImpl implements ITmstrainPleaseApproveResultService {

    @Autowired
    private TmstrainPleaseApproveResultMapper tmstrainPleaseApproveResultMapper;


    /**
     * 查询所有请车计划
     * 1采购进口矿（万州港-达州站/万州港-老区轨道衡） 2采购进口矿（海港-老区轨道衡） 3采购国产矿  4内转
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getAllWagonPlease(Map<String, Object> mapValue) {
        BigDecimal resultType = DataChange.dataToBigDecimal(mapValue.get("resultType"));
        switch (resultType.intValue()){
            case 1:
            case 3:
                return tmstrainPleaseApproveResultMapper.getAllWagonPlease(mapValue); //api:57
            case 4:
                return tmstrainPleaseApproveResultMapper.selectPleaseApprovePlanForConverted(mapValue);//api:253
        }
        return null;
    }

    /**
     * 查询所有批车作业
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getAllApproveWagonPlease(Map<String, Object> mapValue) {
        BigDecimal resultType = DataChange.dataToBigDecimal(mapValue.get("resultType"));
        switch (resultType.intValue()){
            case 1:
            case 3:
                return tmstrainPleaseApproveResultMapper.getAllApproveWagonPlease(mapValue); //apiID: 70
            case 4:
                return tmstrainPleaseApproveResultMapper.selectPleaseApprovePlanForConverted(mapValue); //api:254
        }
        return null;
    }


    /**
     * 获取最大主键ID
     * @return
     */
    @Override
    public BigDecimal selectMaxId() {
        return tmstrainPleaseApproveResultMapper.selectMaxId();
    }

    /**
     * 新增请车作业
     * @param tmstrainPleaseApproveResult 请车批车实绩
     * @return
     */
    @Override
    public int insertSelective(TmstrainPleaseApproveResult tmstrainPleaseApproveResult) {
        //生成主键ID
        BigDecimal maxId = selectMaxId();
        int id = maxId.intValue();
        tmstrainPleaseApproveResult.setResultId(maxId);
        //设置状态 新增的为未下发状态
        tmstrainPleaseApproveResult.setStatus(new BigDecimal(0));
        //生成请车计划号
        String resultPleasePlanNo = DataChange.generateEightDigitsNumber("WQCJH", id);
        tmstrainPleaseApproveResult.setResultPleasePlanNo(resultPleasePlanNo);
        //生成请车日期
        tmstrainPleaseApproveResult.setInsertUsername("admin");
        tmstrainPleaseApproveResult.setResultPleaseDate(new Date());
        return tmstrainPleaseApproveResultMapper.insertSelective(tmstrainPleaseApproveResult);
    }

    /**
     * 修改、下发、删除请车作业  修改、删除批车作业
     * @param tmstrainPleaseApproveResult
     * @return
     */
    @Override
    public int updateByPrimaryKeySelective(TmstrainPleaseApproveResult tmstrainPleaseApproveResult) {
        return tmstrainPleaseApproveResultMapper.updateByPrimaryKeySelective(tmstrainPleaseApproveResult);
    }


    /**
     * 通过ID查询批车作业
     * @param resultId
     * @return
     */
    @Override
    public List<Map<String, Object>> getApproveWagonPleaseById(Integer resultId) {
        return tmstrainPleaseApproveResultMapper.getApproveWagonPleaseById(resultId);
    }

    /**
     * 通过Id查询请车作业 用于修改
     * @return
     */
    @Override
    public List<Map<String, Object>> getWagonPleaseById(Integer resultId) {
        return tmstrainPleaseApproveResultMapper.getWagonPleaseById(resultId);
    }

    /**
     * 内转物流，新增请车计划
     * @param map
     * @return
     */
    @Override
    public int addPleaseForNZ(Map<String, Object> map) {
        //生成主键ID
        BigDecimal maxId = selectMaxId();
        int id = maxId.intValue();
        TmstrainPleaseApproveResult tmstrainPleaseApproveResult = new TmstrainPleaseApproveResult();
        //新增请车id
        tmstrainPleaseApproveResult.setResultId(maxId);
        //设置状态 新增的为未下发状态
        tmstrainPleaseApproveResult.setStatus(new BigDecimal(0));
        tmstrainPleaseApproveResult.setResultType(new BigDecimal(4));//内转
        //生成请车计划号
        String resultPleasePlanNo = DataChange.generateEightDigitsNumber("WQCJH", id);
        tmstrainPleaseApproveResult.setResultPleasePlanNo(resultPleasePlanNo);
        //新增请车人
        tmstrainPleaseApproveResult.setInsertUsername("admin");
//        Integer personnelId =(Integer) map.get("personnelId");
//        String personelName=tmstrainPleaseApproveResultMapper.selectPersonNameByPersonnelId(personnelId);
//        tmstrainPleaseApproveResult.setInsertUsername(personelName);
        //设置发运计划id
        tmstrainPleaseApproveResult.setRailPlanId(DataChange.dataToBigDecimal(map.get("railPlanId")));
        //设置请车数
        tmstrainPleaseApproveResult.setResultPleaseNumber(DataChange.dataToBigDecimal(map.get("resultPleaseNumber")));
        //设置请车时日期
        tmstrainPleaseApproveResult.setResultPleaseDate(new Date((long) map.get("resultPleaseDate")));
        tmstrainPleaseApproveResult.setInsertTime(new Date());
        return tmstrainPleaseApproveResultMapper.insertSelective(tmstrainPleaseApproveResult);
    }

    @Override
    public List<Map<String, Object>> getArrivalSend() {
        return tmstrainPleaseApproveResultMapper.getArrivalSend();
    }

    @Override
    public List<Map<String, Object>> selectPleaseApprovePlanForConverted(Map<String, Object> map) {
        return tmstrainPleaseApproveResultMapper.selectPleaseApprovePlanForConverted(map);
    }

    /**
     * 获取请车计划号
     * @return
     */
    @Override
    public List<Map<String, Object>> getPleasePlanNo() {
        return tmstrainPleaseApproveResultMapper.getPleasePlanNo();
    }
    //通过id渲染请车作业
    @Override
    public List<Map<String, Object>> selectPleasePlanByResultId(Integer resultId) {
        return tmstrainPleaseApproveResultMapper.selectPleasePlanByResultId(resultId);
    }
   //通过id渲染批车作业
    @Override
    public List<Map<String, Object>> selectApproveBYResultId(Integer resultId) {
        return tmstrainPleaseApproveResultMapper.selectApproveBYResultId(resultId);
    }


    /**
     * 获取收货单位
     * @return
     */
    @Override
    public List<Map<String, Object>> getShipper() {
        return tmstrainPleaseApproveResultMapper.getShipper();
    }

    /**
     * 获取发运计划
     * @return
     */
    @Override
    public List<Map<String, Object>> getRailPlan() {
        return tmstrainPleaseApproveResultMapper.getRailPlan();
    }



}
